package com.spring.series.mvc.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

@Controller
@RequestMapping("/controller")
public class MyFirstMVController {

	// http://localhost:8081/SpringMVC-Annotation/controller/

	/**
	 * this is default request handler, when there is no specific method-level mapping after class-level mapping
	 * 
	 * request type = GET
	 * 
	 * http://localhost:8081/SpringMVC-Annotation/controller/
	 * 
	 */
	@RequestMapping(value="/", method=RequestMethod.GET)
	public String defaultMultiControllerAction() {
		return "default";
	}

	// http://localhost:8081/SpringMVC-Annotation/controller/firstmvc.htm

	/**
	 * this is the same controller, as seen in the first example
	 * 
	 *  request type = GET
	 * 
	 * http://localhost:8081/SpringMVC-Annotation/controller/firstmvc.htm
	 * 
	 */
	@RequestMapping(value="/firstmvc.htm", method=RequestMethod.GET)
	public ModelAndView firstMVController() {

		ModelAndView modelAndView = new ModelAndView("showMessage");
		modelAndView.addObject("message", "Welcome To Spring MVC Annotation based web application");
		return modelAndView;
	}

	// http://localhost:8081/SpringMVC-Annotation/controller/hello.htm?guestName=Shaz

	/**
	 * a simple example with get request appending input arguments in the URL after question(?) mark 
	 * 
	 * request type = GET
	 * 
	 * http://localhost:8081/SpringMVC-Annotation/controller/hello.htm?guestName=Shaz
	 * 
	 */
	@RequestMapping(value="/hello.htm", method=RequestMethod.GET)
	public String sayHelloToGuestUser(@RequestParam(required=false, defaultValue="User") String guestName, Model model) {

		model.addAttribute("user", "Hello " + guestName);	
		return "hello";	
	}

	// http://localhost:8081/SpringMVC-Annotation/controller/login.htm

	/**
	 * a POST request with input arguments as login credentials to the web page
	 * 
	 * request type = POST
	 * 
	 * http://localhost:8081/SpringMVC-Annotation/controller/login
	 * userName = admin
	 * password = admin123
	 * 
	 */
	@RequestMapping(value="/login.htm", method=RequestMethod.POST)
	public String loginToWeb(@RequestParam(required=true) String userName, @RequestParam(required=true) String password) {

		if((null != userName && "admin".equalsIgnoreCase(userName)) && (null != password && "admin123".equalsIgnoreCase(password))){
			return "success";
		}
		return "error";
	}
}